summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/buttongroup.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/buttongroup.h')
-rw-r--r--kalarm/lib/buttongroup.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kalarm/lib/buttongroup.h b/kalarm/lib/buttongroup.h
index 1d647b42..8fbadae7 100644
--- a/kalarm/lib/buttongroup.h
+++ b/kalarm/lib/buttongroup.h
@@ -1,5 +1,5 @@
/*
* buttongroup.h - QButtonGroup with an extra signal and Qt 2 compatibility
* Program: kalarm
* Copyright © 2002,2004,2006 by David Jarvie <software@astrojar.org.uk>
*
@@ -20,17 +20,17 @@
#ifndef BUTTONGROUP_H
#define BUTTONGROUP_H
-#include <qbuttongroup.h>
+#include <tqbuttongroup.h>
/**
* @short A QButtonGroup with signal on new selection, plus Qt 2 compatibility.
*
* The ButtonGroup class provides an enhanced version of the QButtonGroup class.
*
* It emits an additional signal, buttonSet(int), whenever any of its buttons
* changes state, for whatever reason, including programmatic control. (The
* QButtonGroup class only emits signals when buttons are clicked on by the user.)
* The class also provides Qt 2 compatibility.
*
* @author David Jarvie <software@astrojar.org.uk>
@@ -43,20 +43,20 @@ class ButtonGroup : public QButtonGroup
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit ButtonGroup(QWidget* parent, const char* name = 0);
+ explicit ButtonGroup(TQWidget* parent, const char* name = 0);
/** Constructor.
* @param title The title displayed for this button group.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(const QString& title, QWidget* parent, const char* name = 0);
+ ButtonGroup(const TQString& title, TQWidget* parent, const char* name = 0);
/** Constructor.
* @param strips The number of rows or columns of buttons.
* @param orient The orientation (Qt::Horizontal or Qt::Vertical) of the button group.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(int strips, Qt::Orientation orient, QWidget* parent, const char* name = 0);
+ ButtonGroup(int strips, Qt::Orientation orient, TQWidget* parent, const char* name = 0);
/** Constructor.
* @param strips The number of rows or columns of buttons.
* @param orient The orientation (Qt::Horizontal or Qt::Vertical) of the button group.
@@ -64,19 +64,19 @@ class ButtonGroup : public QButtonGroup
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(int strips, Qt::Orientation orient, const QString& title, QWidget* parent, const char* name = 0);
+ ButtonGroup(int strips, Qt::Orientation orient, const TQString& title, TQWidget* parent, const char* name = 0);
/** Inserts a button in the group.
* This overrides the insert() method of QButtonGroup, which should really be a virtual method...
* @param button The button to insert.
* @param id The identifier for the button.
* @return The identifier of the inserted button.
*/
- int insert(QButton* button, int id = -1);
+ int insert(TQButton* button, int id = -1);
/** Sets the button with the specified identifier to be on. If this is an exclusive group,
* all other buttons in the group will be set off. The buttonSet() signal is emitted.
* @param id The identifier of the button to set on.
*/
- virtual void setButton(int id) { QButtonGroup::setButton(id); emit buttonSet(id); }
+ virtual void setButton(int id) { TQButtonGroup::setButton(id); emit buttonSet(id); }
private slots:
void slotButtonToggled(bool);
signals:
@@ -1,5 +1,5 @@
/*
- * buttongroup.h - QButtonGroup with an extra signal and Qt 2 compatibility
+ * buttongroup.h - TQButtonGroup with an extra signal and Qt 2 compatibility
* Program: kalarm
* Copyright © 2002,2004,2006 by David Jarvie <software@astrojar.org.uk>
@@ -20,17 +20,17 @@
/**
- * @short A QButtonGroup with signal on new selection, plus Qt 2 compatibility.
+ * @short A TQButtonGroup with signal on new selection, plus Qt 2 compatibility.
*
@@ -20,17 +20,17 @@
*
- * The ButtonGroup class provides an enhanced version of the QButtonGroup class.
+ * The ButtonGroup class provides an enhanced version of the TQButtonGroup class.
*
* It emits an additional signal, buttonSet(int), whenever any of its buttons
@@ -20,17 +20,17 @@
* It emits an additional signal, buttonSet(int), whenever any of its buttons
* changes state, for whatever reason, including programmatic control. (The
- * QButtonGroup class only emits signals when buttons are clicked on by the user.)
+ * TQButtonGroup class only emits signals when buttons are clicked on by the user.)
* The class also provides Qt 2 compatibility.
*
@@ -64,19 +64,19 @@ class ButtonGroup : public QButtonGroup
/** Inserts a button in the group.
- * This overrides the insert() method of QButtonGroup, which should really be a virtual method...
+ * This overrides the insert() method of TQButtonGroup, which should really be a virtual method...
* @param button The button to insert.
* @param id The identifier for the button.